@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,14 +22,12 @@
 #include <QWidget>
 #include "messagecomposer_export.h"
 
-class KComboBox;
-namespace Ui
-{
+class QComboBox;
+namespace Ui {
 class ImageScalingWidget;
 }
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class ImageScalingWidgetPrivate;
 class MESSAGECOMPOSER_EXPORT ImageScalingWidget : public QWidget
 {
@@ -53,7 +51,7 @@ private Q_SLOTS:
 
 private:
     void updateFilterSourceTypeSettings();
-    void initComboBox(KComboBox *combo);
+    void initComboBox(QComboBox *combo);
     void initWriteImageFormat();
     void updateEmailsFilterTypeSettings();
     void updateSettings();
