@@ -22,15 +22,14 @@
 using namespace MessageComposer;
 
 ActionType::ActionType()
-    : mAction(nullptr),
-      mType(Tools)
+    : mAction(nullptr)
+    , mType(Tools)
 {
-
 }
 
 ActionType::ActionType(QAction *action, ActionType::Type type)
-    : mAction(action),
-      mType(type)
+    : mAction(action)
+    , mType(type)
 {
 }
 
@@ -48,23 +47,19 @@ class MessageComposer::PluginEditorInterfacePrivate
 {
 public:
     PluginEditorInterfacePrivate()
-        : mParentWidget(nullptr),
-          mRichTextEditor(nullptr),
-          plugin(nullptr)
     {
-
     }
+
     ActionType mActionType;
-    QWidget *mParentWidget;
-    KPIMTextEdit::RichTextEditor *mRichTextEditor;
-    PluginEditor *plugin;
+    QWidget *mParentWidget = nullptr;
+    KPIMTextEdit::RichTextEditor *mRichTextEditor = nullptr;
+    PluginEditor *plugin = nullptr;
 };
 
 PluginEditorInterface::PluginEditorInterface(QObject *parent)
-    : PimCommon::AbstractGenericPluginInterface(parent),
-      d(new MessageComposer::PluginEditorInterfacePrivate)
+    : PimCommon::AbstractGenericPluginInterface(parent)
+    , d(new MessageComposer::PluginEditorInterfacePrivate)
 {
-
 }
 
 PluginEditorInterface::~PluginEditorInterface()
@@ -114,4 +109,3 @@ QString PluginEditorInterface::actionXmlExtension(ActionType::Type type)
     }
     return {};
 }
-
