@@ -21,7 +21,6 @@
 #include "MessageCore/AttachmentFromUrlBaseJob"
 #include "attachmentfromurljob.h"
 #include "attachmentupdatejob.h"
-#include <QUrl>
 #include "attachmentfromurlutils.h"
 #include "messagecore_debug.h"
 #include <QTimer>
@@ -58,7 +57,9 @@ void AttachmentUpdateJob::Private::doStart()
         return;
     }
     MessageCore::AttachmentFromUrlBaseJob *job = MessageCore::AttachmentFromUrlUtils::createAttachmentJob(mOriginalPart->url(), q);
-    connect(job, SIGNAL(result(KJob*)), q, SLOT(loadJobResult(KJob*)));
+    connect(job, &AttachmentFromUrlBaseJob::result, q, [this](KJob *job) {
+        loadJobResult(job);
+    });
     job->start();
 }
 
@@ -86,8 +87,8 @@ void AttachmentUpdateJob::Private::loadJobResult(KJob *job)
 }
 
 AttachmentUpdateJob::AttachmentUpdateJob(const AttachmentPart::Ptr &part, QObject *parent)
-    : KJob(parent),
-      d(new Private(this))
+    : KJob(parent)
+    , d(new Private(this))
 {
     d->mOriginalPart = part;
 }
@@ -99,7 +100,9 @@ AttachmentUpdateJob::~AttachmentUpdateJob()
 
 void AttachmentUpdateJob::start()
 {
-    QTimer::singleShot(0, this, SLOT(doStart()));
+    QTimer::singleShot(0, this, [this]() {
+        d->doStart();
+    });
 }
 
 AttachmentPart::Ptr AttachmentUpdateJob::originalPart() const
