@@ -60,7 +60,7 @@ public:
     MessageViewer::HeaderStyleUtil headerStyleUtil;
     QSharedPointer<Grantlee::FileSystemTemplateLoader> templateLoader;
     int iconSize;
-    Grantlee::Engine *engine;
+    Grantlee::Engine *engine = nullptr;
 };
 
 GrantleeHeaderFormatter::GrantleeHeaderFormatter()
@@ -90,13 +90,11 @@ QString GrantleeHeaderFormatter::toHtml(
     return format(
         settings.theme.absolutePath(), headerTemplate,
         settings.theme.displayExtraVariables(), settings.isPrinting, settings.style, settings.message,
-        settings.showMailAction, settings.showEmoticons);
+        settings.showEmoticons);
 }
 
-QString GrantleeHeaderFormatter::toHtml(const QStringList &displayExtraHeaders,
-                                        const QString &absolutPath, const QString &filename,
-                                        const MessageViewer::HeaderStyle *style,
-                                        KMime::Message *message, bool isPrinting) const
+QString GrantleeHeaderFormatter::toHtml(const QStringList &displayExtraHeaders, const QString &absolutPath, const QString &filename, const MessageViewer::HeaderStyle *style, KMime::Message *message,
+                                        bool isPrinting) const
 {
     d->templateLoader->setTemplateDirs(QStringList() << absolutPath);
     Grantlee::Template headerTemplate = d->engine->loadByName(filename);
@@ -106,11 +104,8 @@ QString GrantleeHeaderFormatter::toHtml(const QStringList &displayExtraHeaders,
     return format(absolutPath, headerTemplate, displayExtraHeaders, isPrinting, style, message);
 }
 
-QString GrantleeHeaderFormatter::format(const QString &absolutePath,
-                                        const Grantlee::Template &headerTemplate,
-                                        const QStringList &displayExtraHeaders, bool isPrinting,
-                                        const MessageViewer::HeaderStyle *style,
-                                        KMime::Message *message, bool showMailAction, bool showEmoticons) const
+QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grantlee::Template &headerTemplate, const QStringList &displayExtraHeaders, bool isPrinting,
+                                        const MessageViewer::HeaderStyle *style, KMime::Message *message, bool showEmoticons) const
 {
     QVariantHash headerObject;
 
@@ -121,7 +116,6 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath,
     // direction.
     const QString absoluteThemePath = QUrl::fromLocalFile(absolutePath + QLatin1Char('/')).url();
     headerObject.insert(QStringLiteral("absoluteThemePath"), absoluteThemePath);
-    headerObject.insert(QStringLiteral("showMailAction"), showMailAction);
     headerObject.insert(QStringLiteral("applicationDir"),
                         QApplication::isRightToLeft() ? QStringLiteral("rtl") : QStringLiteral(
                             "ltr"));
@@ -251,18 +245,6 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath,
                                                                                    HeaderStyleUtil::
                                                                                    LongDate)));
 
-    if (MessageViewer::MessageViewerSettings::self()->showUserAgent()) {
-        if (auto hdr = message->userAgent(false)) {
-            headerObject.insert(QStringLiteral("useragent"),
-                                d->headerStyleUtil.strToHtml(hdr->asUnicodeString()));
-        }
-
-        if (auto hrd = message->headerByType("X-Mailer")) {
-            headerObject.insert(QStringLiteral("xmailer"),
-                                d->headerStyleUtil.strToHtml(hrd->asUnicodeString()));
-        }
-    }
-
     if (message->hasHeader("Resent-From")) {
         headerObject.insert(QStringLiteral("resentfromi18n"), i18n("resent from"));
         const QVector<KMime::Types::Mailbox> resentFrom
@@ -308,10 +290,10 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath,
     QString linkColor = QStringLiteral("white");
     const QColor activeColor
         = KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
-    QColor activeColorDark = activeColor.dark(130);
+    QColor activeColorDark = activeColor.darker(130);
     // reverse colors for encapsulated
     if (!style->isTopLevel()) {
-        activeColorDark = activeColor.dark(50);
+        activeColorDark = activeColor.darker(50);
         fontColor = QColor(Qt::black);
         linkColor = QStringLiteral("black");
     }
@@ -352,12 +334,10 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath,
                                                                                                        iconPath).url(),
                                                                                                    QString::number(
                                                                                                        d
-        ->iconSize));
+                                                                                                       ->iconSize));
         headerObject.insert(QStringLiteral("attachmentIcon"), html);
     }
 
-    //Action
-    d->headerStyleUtil.addMailAction(headerObject);
     QVariantHash mapping;
     mapping.insert(QStringLiteral("header"), headerObject);
     Grantlee::Context context(mapping);
