@@ -22,8 +22,7 @@
 
 #include <WebEngineViewer/NetworkPluginUrlInterceptorInterface>
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class CidReferencesUrlInterceptor : public WebEngineViewer::NetworkPluginUrlInterceptorInterface
 {
     Q_OBJECT
@@ -31,7 +30,7 @@ public:
     explicit CidReferencesUrlInterceptor(QObject *parent = nullptr);
     ~CidReferencesUrlInterceptor();
 
-    bool interceptRequest(QWebEngineUrlRequestInfo &info) Q_DECL_OVERRIDE;
+    bool interceptRequest(QWebEngineUrlRequestInfo &info) override;
 };
 }
 #endif // CIDREFERENCESURLINTERCEPTOR_H
