@@ -23,18 +23,14 @@
 #include "interfaces/bodypartformatter.h"
 #include "interfaces/bodypart.h"
 
-namespace MimeTreeParser
-{
-
+namespace MimeTreeParser {
 class MultiPartAlternativeBodyPartFormatter : public Interface::BodyPartFormatter
 {
     static const MultiPartAlternativeBodyPartFormatter *self;
 public:
-    Interface::MessagePart::Ptr process(Interface::BodyPart &part) const override;
-    using Interface::BodyPartFormatter::format;
+    MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
-
 }
 
 #endif
