@@ -34,16 +34,16 @@ class TemplateParser::CustomTemplatesMenuPrivate
 {
 public:
     CustomTemplatesMenuPrivate()
-        : mOwnerActionCollection(nullptr),
-          mCustomReplyActionMenu(nullptr),
-          mCustomReplyAllActionMenu(nullptr),
-          mCustomForwardActionMenu(nullptr),
-          mCustomReplyMapper(nullptr),
-          mCustomReplyAllMapper(nullptr),
-          mCustomForwardMapper(nullptr)
+        : mOwnerActionCollection(nullptr)
+        , mCustomReplyActionMenu(nullptr)
+        , mCustomReplyAllActionMenu(nullptr)
+        , mCustomForwardActionMenu(nullptr)
+        , mCustomReplyMapper(nullptr)
+        , mCustomReplyAllMapper(nullptr)
+        , mCustomForwardMapper(nullptr)
     {
-
     }
+
     ~CustomTemplatesMenuPrivate()
     {
         delete mCustomReplyActionMenu;
@@ -54,20 +54,21 @@ public:
         delete mCustomReplyAllMapper;
         delete mCustomForwardMapper;
     }
-    KActionCollection *mOwnerActionCollection;
+
+    KActionCollection *mOwnerActionCollection = nullptr;
 
     QStringList mCustomTemplates;
     QList<QAction *> mCustomTemplateActions;
 
     // Custom template actions menu
-    KActionMenu *mCustomReplyActionMenu;
-    KActionMenu *mCustomReplyAllActionMenu;
-    KActionMenu *mCustomForwardActionMenu;
+    KActionMenu *mCustomReplyActionMenu = nullptr;
+    KActionMenu *mCustomReplyAllActionMenu = nullptr;
+    KActionMenu *mCustomForwardActionMenu = nullptr;
 
     // Signal mappers for custom template actions
-    QSignalMapper *mCustomReplyMapper;
-    QSignalMapper *mCustomReplyAllMapper;
-    QSignalMapper *mCustomForwardMapper;
+    QSignalMapper *mCustomReplyMapper = nullptr;
+    QSignalMapper *mCustomReplyAllMapper = nullptr;
+    QSignalMapper *mCustomForwardMapper = nullptr;
 };
 
 CustomTemplatesMenu::CustomTemplatesMenu(QWidget *owner, KActionCollection *ac)
@@ -76,28 +77,25 @@ CustomTemplatesMenu::CustomTemplatesMenu(QWidget *owner, KActionCollection *ac)
     d->mOwnerActionCollection = ac;
 
     d->mCustomForwardActionMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-forward-custom")),
-            i18n("With Custom Template"), owner);
+                                                  i18n("With Custom Template"), owner);
     d->mOwnerActionCollection->addAction(QStringLiteral("custom_forward"), d->mCustomForwardActionMenu);
 
     d->mCustomReplyActionMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-reply-custom")),
-            i18n("Reply With Custom Template"), owner);
+                                                i18n("Reply With Custom Template"), owner);
     d->mOwnerActionCollection->addAction(QStringLiteral("custom_reply"), d->mCustomReplyActionMenu);
 
     d->mCustomReplyAllActionMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-reply-all-custom")),
-            i18n("Reply to All With Custom Template"), owner);
+                                                   i18n("Reply to All With Custom Template"), owner);
     d->mOwnerActionCollection->addAction(QStringLiteral("custom_reply_all"), d->mCustomReplyAllActionMenu);
 
     d->mCustomForwardMapper = new QSignalMapper(this);
-    connect(d->mCustomForwardMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-            this, &CustomTemplatesMenu::slotForwardSelected);
+    connect(d->mCustomForwardMapper, QOverload<int>::of(&QSignalMapper::mapped), this, &CustomTemplatesMenu::slotForwardSelected);
 
     d->mCustomReplyMapper = new QSignalMapper(this);
-    connect(d->mCustomReplyMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-            this, &CustomTemplatesMenu::slotReplySelected);
+    connect(d->mCustomReplyMapper, QOverload<int>::of(&QSignalMapper::mapped), this, &CustomTemplatesMenu::slotReplySelected);
 
     d->mCustomReplyAllMapper = new QSignalMapper(this);
-    connect(d->mCustomReplyAllMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-            this, &CustomTemplatesMenu::slotReplyAllSelected);
+    connect(d->mCustomReplyAllMapper, QOverload<int>::of(&QSignalMapper::mapped), this, &CustomTemplatesMenu::slotReplyAllSelected);
 
     update();
 }
@@ -160,7 +158,7 @@ void CustomTemplatesMenu::update()
 
         const QString nameActionName = nameAction.replace(QLatin1Char(' '), QLatin1Char('_'));
 
-        QAction *action;
+        QAction *action = nullptr;
         switch (t.type()) {
         case CustomTemplates::TReply:
             action = new QAction(nameAction, d->mOwnerActionCollection);   //krazy:exclude=tipsandthis
@@ -223,20 +221,20 @@ void CustomTemplatesMenu::update()
     }
 
     if (!replyc) {
-        QAction *noAction =
-            d->mCustomReplyActionMenu->menu()->addAction(i18n("(no custom templates)"));
+        QAction *noAction
+            = d->mCustomReplyActionMenu->menu()->addAction(i18n("(no custom templates)"));
         noAction->setEnabled(false);
         d->mCustomReplyActionMenu->setEnabled(false);
     }
     if (!replyallc) {
-        QAction *noAction =
-            d->mCustomReplyAllActionMenu->menu()->addAction(i18n("(no custom templates)"));
+        QAction *noAction
+            = d->mCustomReplyAllActionMenu->menu()->addAction(i18n("(no custom templates)"));
         noAction->setEnabled(false);
         d->mCustomReplyAllActionMenu->setEnabled(false);
     }
     if (!forwardc) {
-        QAction *noAction =
-            d->mCustomForwardActionMenu->menu()->addAction(i18n("(no custom templates)"));
+        QAction *noAction
+            = d->mCustomForwardActionMenu->menu()->addAction(i18n("(no custom templates)"));
         noAction->setEnabled(false);
         d->mCustomForwardActionMenu->setEnabled(false);
     }
@@ -256,4 +254,3 @@ void CustomTemplatesMenu::slotForwardSelected(int idx)
 {
     Q_EMIT forwardTemplateSelected(d->mCustomTemplates.at(idx));
 }
-
