@@ -34,12 +34,12 @@ class WebEngineViewer::CreatePhishingUrlDataBaseJobPrivate
 {
 public:
     CreatePhishingUrlDataBaseJobPrivate()
-        : mContraintsCompressionType(CreatePhishingUrlDataBaseJob::RawCompression),
-          mDataBaseDownloadNeeded(CreatePhishingUrlDataBaseJob::FullDataBase),
-          mNetworkAccessManager(nullptr)
+        : mContraintsCompressionType(CreatePhishingUrlDataBaseJob::RawCompression)
+        , mDataBaseDownloadNeeded(CreatePhishingUrlDataBaseJob::FullDataBase)
+        , mNetworkAccessManager(nullptr)
     {
-
     }
+
     UpdateDataBaseInfo::CompressionType parseCompressionType(const QString &str);
     RiceDeltaEncoding parseRiceDeltaEncoding(const QMap<QString, QVariant> &map);
     QVector<Removal> parseRemovals(const QVariantList &lst);
@@ -47,12 +47,12 @@ public:
     QString mDataBaseState;
     CreatePhishingUrlDataBaseJob::ContraintsCompressionType mContraintsCompressionType;
     CreatePhishingUrlDataBaseJob::DataBaseDownloadType mDataBaseDownloadNeeded;
-    QNetworkAccessManager *mNetworkAccessManager;
+    QNetworkAccessManager *mNetworkAccessManager = nullptr;
 };
 
 CreatePhishingUrlDataBaseJob::CreatePhishingUrlDataBaseJob(QObject *parent)
-    : QObject(parent),
-      d(new CreatePhishingUrlDataBaseJobPrivate)
+    : QObject(parent)
+    , d(new CreatePhishingUrlDataBaseJobPrivate)
 {
     d->mNetworkAccessManager = new QNetworkAccessManager(this);
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &CreatePhishingUrlDataBaseJob::slotDownloadDataBaseFinished);
@@ -87,7 +87,7 @@ void CreatePhishingUrlDataBaseJob::start()
         qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         //curl -H "Content-Type: application/json" -X POST -d '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}' https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
-        connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &CreatePhishingUrlDataBaseJob::slotError);
+        connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &CreatePhishingUrlDataBaseJob::slotError);
     }
 }
 
@@ -108,22 +108,22 @@ QByteArray CreatePhishingUrlDataBaseJob::jsonRequest() const
 {
 #if 0
     {
-    "client": {
-        "clientId":       "yourcompanyname",
-        "clientVersion":  "1.5.2"
+        "client" : {
+            "clientId" :       "yourcompanyname",
+            "clientVersion" :  "1.5.2"
         },
-    "listUpdateRequests": [{
-        "threatType":      "MALWARE",
-        "platformType":    "WINDOWS",
-        "threatEntryType": "URL",
-        "state":           "Gg4IBBADIgYQgBAiAQEoAQ==",
-        "constraints": {
-                "maxUpdateEntries":      2048,
-                "maxDatabaseEntries":    4096,
-            "region":                "US",
-            "supportedCompressions": ["RAW"]
-            }
-        }]
+        "listUpdateRequests" : [{
+                                    "threatType" :      "MALWARE",
+                                    "platformType" :    "WINDOWS",
+                                    "threatEntryType" : "URL",
+                                    "state" :           "Gg4IBBADIgYQgBAiAQEoAQ==",
+                                    "constraints" : {
+                                        "maxUpdateEntries" :      2048,
+                                        "maxDatabaseEntries" :    4096,
+                                        "region" :                "US",
+                                        "supportedCompressions" : ["RAW"]
+                                    }
+                                }]
     }
 #endif
     QVariantMap clientMap;
@@ -299,6 +299,7 @@ QVector<Removal> CreatePhishingUrlDataBaseJobPrivate::parseRemovals(const QVaria
                         if (rawIndicesIt.key() == QStringLiteral("indices")) {
                             const QVariantList lst = rawIndicesIt.value().toList();
                             QList<quint32> indexList;
+                            indexList.reserve(lst.count());
                             for (const QVariant &var : lst) {
                                 indexList.append(var.toUInt());
                             }
@@ -406,4 +407,3 @@ void CreatePhishingUrlDataBaseJob::setContraintsCompressionType(CreatePhishingUr
 {
     d->mContraintsCompressionType = type;
 }
-
