@@ -19,7 +19,6 @@
 
 #include "searchfullhashjob.h"
 
-
 #include "checkphishingurlutil.h"
 #include <QNetworkAccessManager>
 #include <QNetworkConfigurationManager>
@@ -37,18 +36,18 @@ public:
     SearchFullHashJobPrivate()
         : mNetworkAccessManager(nullptr)
     {
-
     }
+
     bool foundExactHash(const QList<QByteArray> &listLongHash);
     QHash<QByteArray, QByteArray> mHashs;
     QUrl mUrl;
     QStringList mDatabaseHashes;
-    QNetworkAccessManager *mNetworkAccessManager;
+    QNetworkAccessManager *mNetworkAccessManager = nullptr;
 };
 
 SearchFullHashJob::SearchFullHashJob(QObject *parent)
-    : QObject(parent),
-      d(new SearchFullHashJobPrivate)
+    : QObject(parent)
+    , d(new SearchFullHashJobPrivate)
 {
     d->mNetworkAccessManager = new QNetworkAccessManager(this);
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &SearchFullHashJob::slotCheckUrlFinished);
@@ -112,14 +111,14 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
         } else {
             const QVariantList info = answer.value(QStringLiteral("matches")).toList();
             //TODO
-            const QString minimumWaitDuration = answer.value(QStringLiteral("minimumWaitDuration")).toString();
-            const QString negativeCacheDuration = answer.value(QStringLiteral("negativeCacheDuration")).toString();
+            //const QString minimumWaitDuration = answer.value(QStringLiteral("minimumWaitDuration")).toString();
+            //const QString negativeCacheDuration = answer.value(QStringLiteral("negativeCacheDuration")).toString();
             //Implement multi match ?
             if (info.count() == 1) {
                 const QVariantMap map = info.at(0).toMap();
                 const QString threatTypeStr = map[QStringLiteral("threatType")].toString();
 
-                const QString cacheDuration = map[QStringLiteral("cacheDuration")].toString();
+                //const QString cacheDuration = map[QStringLiteral("cacheDuration")].toString();
 
                 if (threatTypeStr == QStringLiteral("MALWARE")) {
                     const QVariantMap urlMap = map[QStringLiteral("threat")].toMap();
@@ -258,7 +257,7 @@ void SearchFullHashJob::start()
         //qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         Q_EMIT debugJson(baPostData);
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
-        connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &SearchFullHashJob::slotError);
+        connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &SearchFullHashJob::slotError);
     } else {
         Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl, d->mUrl);
         deleteLater();
