@@ -17,7 +17,7 @@
  */
 
 #include "findbarwebengineview.h"
-#include "PimCommon/LineEditWithCompleter"
+#include <PimCommon/LineEditWithCompleterNg>
 #include <QWebEngineView>
 #include <QAction>
 
@@ -27,16 +27,15 @@ class WebEngineViewer::FindBarWebEngineViewPrivate
 {
 public:
     FindBarWebEngineViewPrivate()
-        : mView(nullptr)
     {
-
     }
-    QWebEngineView *mView;
+
+    QWebEngineView *mView = nullptr;
 };
 
 FindBarWebEngineView::FindBarWebEngineView(QWebEngineView *view, QWidget *parent)
-    : FindBarBase(parent),
-      d(new WebEngineViewer::FindBarWebEngineViewPrivate)
+    : FindBarBase(parent)
+    , d(new WebEngineViewer::FindBarWebEngineViewPrivate)
 {
     d->mView = view;
 }
@@ -85,4 +84,3 @@ void FindBarWebEngineView::clearSelections()
     mLastSearchStr.clear();
     FindBarBase::clearSelections();
 }
-
